@@ -1,6 +1,5 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from collections import OrderedDict
+
 from .. import Provider as PersonProvider
 
 
